@@ -4,7 +4,7 @@
 
 (autoload 'custom-add-loads "cus-load")
 
-(custom-add-loads 'TeX-fold '("tex-fold"))
+(custom-add-loads 'TeX-fold '("latex" "tex-fold"))
 (custom-add-loads 'AUCTeX-jp '("tex-jp"))
 (custom-add-loads 'tex '("bib-cite" "font-latex" "tex" "texmathp"))
 (custom-add-loads 'ConTeXt-nl-environment '("context-nl"))
