@@ -1,12 +1,12 @@
 ;;; -*- emacs-lisp -*-
 ;;; scrartcl.el -- AUCTeX style for scrartcl.cls
 
-;; Copyright (C) 2002 Free Software Foundation
+;; Copyright (C) 2002, 2005 Free Software Foundation
 ;; License: GPL, see the file COPYING in the base directory of AUCTeX
 
 ;; Author: Mark Trettin <Mark.Trettin@gmx.de>
 ;; Created: 2002-09-26
-;; Version: $Id: scrartcl.el,v 1.7 2008/07/23 07:22:56 stephent Exp $
+;; Version: $Id: scrartcl.el,v 1.4 2005/03/17 10:02:06 angeli Exp $
 ;; Keywords: tex
 
 ;;; Commentary:
@@ -19,7 +19,7 @@
 ;;; Code:
 (TeX-add-style-hook "scrartcl"
    (lambda ()
-     (setq LaTeX-largest-level (LaTeX-section-level "section"))
+     (LaTeX-largest-level-set "section")
      ;; load basic definitons
      (TeX-run-style-hooks "scrbase")))
 
